(css & rules)ex. (css [:h1 {:height :20px}] [:h2 {:height :10px}]) => h1{height:20px;}h2{height:10px}
ex.
(css [:h1 {:height :20px}] [:h2 {:height :10px}])
=> h1{height:20px;}h2{height:10px}(embed-css & rules)Quick and dirty dsl for inline css rules, similar to hiccup.
ex. (css [:h1 {:color "blue"}] [:div.content p {:text-indent "1em"}])
=> h1 {color: blue;} div.content p {text-indent: 1em;}
Quick and dirty dsl for inline css rules, similar to hiccup.
ex. `(css [:h1 {:color "blue"}] [:div.content p {:text-indent "1em"}])`
=> `h1 {color: blue;} div.content p {text-indent: 1em;}`(href href content & opts)ex. (href "http://google.com" "Google!" :rel "nofollow")
ex. (href "http://google.com" "Google!" :rel "nofollow")
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |